@@ -37,31 +37,6 @@ use base 'Perl6::Pod::Block';
 use Test::More;
 use Data::Dumper;
 
-sub _on_para {
-    my ($self , $parser, $txt)  = @_;
-#    diag "on_para";
-    my @parts = split /^\n/m, $txt;
-    diag "on_para : ".scalar(@parts);
-    if ( @parts == 1 ) {
-        return $self->SUPER::on_para($parser, $txt)    
-    }
-    diag "extra process para". Dumper(\@parts);
-    my @res = ();
-    foreach my $txt ( @parts ) {
-    my $para = $parser->current_element->mk_block( $self->local_name, $self->{_pod_options});
-    $para->add_content( $parser->mk_characters( $txt));
-#    push @res, $para;
-    $parser->current_element->add_content($para);
-#    $self->add_content($para);
-    }
-#    $self->delete_element;
-    return undef;
-#    return [ ];
-#    return $txt;
-#    return [$txt, $txt] 
-}
-
-
 sub to_xhtml { 
     my $self = shift;
     my $parser = shift;
@@ -85,7 +60,7 @@ Zahatski Aliaksandr, <zag@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009 by Zahatski Aliaksandr
+Copyright (C) 2009 - 2010  by Zahatski Aliaksandr
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
